#[repr(u32)]
pub enum AccountCompressionError {
IncorrectLeafLength,
ConcurrentMerkleTreeError,
ZeroCopyError,
ConcurrentMerkleTreeConstantsError,
CanopyLengthMismatch,
IncorrectAuthority,
IncorrectAccountOwner,
IncorrectAccountType,
}Expand description
Errors related to misconfiguration or misuse of the Merkle tree
Variants
IncorrectLeafLength
This error is currently not used.
ConcurrentMerkleTreeError
A modification to the tree was invalid and a changelog was not emitted. The proof may be invalid or out-of-date, or the provided leaf hash was invalid.
ZeroCopyError
An issue was detected with loading the provided account data for this ConcurrentMerkleTree.
ConcurrentMerkleTreeConstantsError
See ConcurrentMerkleTreeHeader for valid configuration options.
CanopyLengthMismatch
When using Canopy, the stored byte length should a multiple of the node’s byte length (32 bytes)
IncorrectAuthority
Incorrect authority account provided
IncorrectAccountOwner
Incorrect account owner
IncorrectAccountType
Incorrect account type
Implementations