pub struct AppendCanopyNodes {
pub start_index: u32,
pub canopy_nodes: Vec<[u8; 32]>,
}Expand description
Instruction.
Fields
start_index: u32canopy_nodes: Vec<[u8; 32]>Trait Implementations
Sourceimpl BorshDeserialize for AppendCanopyNodes
impl BorshDeserialize for AppendCanopyNodes
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for AppendCanopyNodes
impl BorshSerialize for AppendCanopyNodes
Sourceimpl Discriminator for AppendCanopyNodes
impl Discriminator for AppendCanopyNodes
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
Sourceimpl InstructionData for AppendCanopyNodes
impl InstructionData for AppendCanopyNodes