pub struct InsertOrAppend {
pub root: [u8; 32],
pub leaf: [u8; 32],
pub index: u32,
}Expand description
Instruction.
Fields
root: [u8; 32]leaf: [u8; 32]index: u32Trait Implementations
Sourceimpl BorshDeserialize for InsertOrAppend
impl BorshDeserialize for InsertOrAppend
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for InsertOrAppend
impl BorshSerialize for InsertOrAppend
Sourceimpl Discriminator for InsertOrAppend
impl Discriminator for InsertOrAppend
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
Sourceimpl InstructionData for InsertOrAppend
impl InstructionData for InsertOrAppend